#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-no-log.rc

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log
rm -f ./tmp/missing-log-dir.txt

export LOG=/nonexistant/msmtpq-ng.log

TS=PASS

if echo "Subject: test missing log dir
       
Mising log dir"| /usr/bin/msmtpq-ng root 2>./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir generates error"

TS=PASS

if ! test -s ./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir error message displayed"

TS=PASS

rm -f ./tmp/missing-log-dir.txt

if /usr/bin/msmtpq-ng-queue 2>./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir for queue generates error for queue"

TS=PASS

if ! test -s ./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir error message displayed for queue"

TS=PASS

if [ "$USER" = "travis" ] || [ "$USER" = "debian" ]; then
	rm -f ~/.msmtpq-ng.rc
	cp ./tmp/msmtpq-fail.rc ~/.msmtpq-ng.rc

	unset MSMTP_SKIP_CONF
	unset MSMTP_OVERRIDE_CONF
	export MSMTP_SKIP_CONF MSMTP_OVERRIDE_CONF

printf "Subject: test 'default' location config\n\nTest a config in a default location\n" | /usr/bin/msmtpq-ng && {
		TS=FAIL
		OTS=FAIL
	}
else
	TS=SKIPPED
fi

echo "$TS: Config in a 'default' location succeeds"

if [ "$TS" != "SKIPPED" ]; then
	/usr/bin/msmtpq-ng-queue || {
		TS=FAIL
		OTS=FAIL
	}
fi

echo "$TS: Config in a 'default' location succeeds for queue list"

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-no-msmtp.rc

TS=PASS

if echo "Subject: test missing msmtp exe
       
Missing executable"| /usr/bin/msmtpq-ng root 2>./tmp/missing-binary.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing msmtp binary generates error"

TS=PASS

if ! test -s ./tmp/missing-binary.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing binary message shown"

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-new-qdir.rc
rm -rf ./tmp/q2

TS=PASS

if ! echo "Subject: test new queue dir
       
Test using a queue dir that doesn't exist yet."| /usr/bin/msmtpq-ng root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new queue dir succeeds"

TS=PASS

if [ -z "$(ls -A ./tmp/q2/* 2>/dev/null)" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: A new queue dir gets used."

rm -rf ./tmp/q2

if ! /usr/bin/msmtpq-ng-queue >./tmp/new-queue-dir-list-queue.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new queue dir succeeds for list queue"

TS=PASS

if [ ! -s ./tmp/new-queue-dir-list-queue.txt ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: A new queue dir gets used for list queue"

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-new-lockdir.rc
rm -rf ./tmp/q3

TS=PASS

if ! echo "Subject: test new lock dir
       
Test using a lock dir that doesn't exist yet."| /usr/bin/msmtpq-ng root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new lock dir succeeds"

rm -rf ./tmp/q3 

if ! /usr/bin/msmtpq-ng-queue; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new lock dir succeeds for list queue"

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-flock.rc
unset LOCK_CMD
export LOCK_CMD
OLDPATH="${PATH}"
export OLDPATH
export PATH="$(pwd)/tests/scripts:${OLDPATH}"

TS=PASS

if ! echo "Subject: test flock substitute
 
Test using flock substitute."| /usr/bin/msmtpq-ng root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a flock substitute succeeds"

TS=PASS

if ! /usr/bin/msmtpq-ng-queue; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a flock substitute succeeds for list queue"

export PATH="/nonexistant"

TS=PASS

if echo "Subject: test missing lock command
       
Test missing lock command."| /usr/bin/msmtpq-ng root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing lock command fails"

TS=PASS

export MSMTPQ_NG=/usr/bin/msmtpq-ng

if /usr/bin/msmtpq-ng-queue; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing lock command fails for list queue"

export PATH="${OLDPATH}"

TS=PASS

if echo "Subject: test missing addressee
       
Test missing addressee command."| /usr/bin/msmtpq-ng; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing addressee fails"

TS=PASS

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-missing-ng.rc

/usr/bin/msmtpq-ng-queue
MQNQRC=$?

if [ "$MQNQRC" != "72" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: For msmtpq-ng-queue a missing msmtpq-ng errors out"

TS=PASS

export MSMTP_MTA_OVERRIDE_CONF=./tmp/msmtpq-ng-missing-ng.rc
export MSMTPQ_NG_QUEUE=/nonexistant
/usr/sbin/msmtpq-ng-queue-mta
MQNQRC=$?

if [ "$MQNQRC" != "72" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: For msmtpq-ng-queue-mta a missing msmtpq-ng-queue errors out"

TS=PASS

export MSMTP_MTA_OVERRIDE_CONF=./tmp/msmtpq-ng-missing-ng.rc
export MSMTPQ_NG=/nonexistant

echo "Subject: test missing mstmpq-ng

Test missing msmtpq-ng for mta" | /usr/sbin/msmtpq-ng-mta root
MQNQRC=$?

if [ "$MQNQRC" != "72" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: For msmtpq-ng-mta a missing msmtpq-ng errors out"

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi
