#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS

rm -rf ./tmp/msmtp.queue.only
rm -f ./tmp/msmtp.queue.only.log

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-queueonly.rc

TS=PASS

echo -n "blah
ehlo localhost
helo localhost
data
rset
blah
quit
" | /usr/bin/msmtpq-ng -bs >./tmp/testbs-1.log

if grep -q "500" ./tmp/testbs-1.log && grep -q "250" ./tmp/testbs-1.log && grep -q "503" ./tmp/testbs-1.log && grep -q "502" ./tmp/testbs-1.log && grep -q "221" ./tmp/testbs-1.log; then
	:
else
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng -bs with deliberately erroneous output fails"

TS=PASS

echo -n "helo localhost
mail from:root
mail from:<root>
mail from:<root@localhost>
rcpt to:root
rcpt to:<root>
noop
data
Subject: Test -bs email

Test -bs email
.

mail from:<msmtp>
mail from:<msmtp@localhost>
rcpt to:blah
rcpt to:<root@localhost>
rcpt to:blah2
rcpt to:<msmtp@localhost>
data
Subject: Test -bs email #2

Test -bs email with second mail from
.

quit
" | /usr/bin/msmtpq-ng -bs >./tmp/testbs-2.log

if grep -q "250" ./tmp/testbs-2.log && grep -q "501" ./tmp/testbs-2.log && grep -q "354" ./tmp/testbs-2.log && grep -q "221" ./tmp/testbs-2.log; then
	if grep -q 'queueing message' ./tmp/msmtp.queue.only.log; then
		if [ -z "$(ls -A ./tmp/msmtp.queue.only/*.mail 2>/dev/null)" ]; then
			TS=FAIL
			OTS=FAIL
		fi
	else
		TS=FAIL
		OTS=FAIL
	fi
else
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng -bs successfully queues message"

MID="$(cat ./tmp/msmtp.queue.only.log|grep 'enqueued mail as : \[ .* \] '|tail -n1|cut -f4 -d\[|cut -f1 -d]|tr -d ' ')"

TS=PASS

/usr/bin/msmtpq-ng-queue -f | grep -qiE '(mail queue is empty|queueing only mode)'
MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng-queue -bp has no non-held messages to display"

TS=PASS

/usr/bin/msmtpq-ng-queue -h ALL #| grep -qi 'too new to release'
/usr/bin/msmtpq-ng-queue -H ALL | grep -qi 'too new to release'

MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng-queue -H ALL has messages too new to release"

TS=PASS

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-queueonly-syslog.rc

/usr/bin/msmtpq-ng-queue -H ALL

sudo journalctl -t msmtpq-ng|grep -q 'too new to release'
MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng-queue -H ALL with syslog and messages too new to release "

TS=PASS

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-queueonly-syslog.rc
sed -i -e 's/^export MSMTP_QUEUE_ONLY=true/export MSMTP_QUEUE_ONLY=false/' ./tmp/msmtpq-ng-queueonly-syslog.rc

/usr/bin/msmtpq-ng -qI "$MID"

sudo journalctl -t msmtpq-ng | grep -q 'too new to unhold'

MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng -q with syslog and messages too new to release "

sed -i -e 's/^export MSMTP_QUEUE_ONLY=false/export MSMTP_QUEUE_ONLY=true/' ./tmp/msmtpq-ng-queueonly-syslog.rc

TS=PASS

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-queueonly.rc
/usr/bin/msmtpq-ng-queue -f | grep -qiE 'mail queue is empty'
MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng-queue -f shows mail queue empty"

TS=PASS

sed -i -e '$a\export MSMTP_MAX_QUEUE_LIFETIME=0' ./tmp/msmtpq-ng-queueonly.rc
sed -i -e 's/^export MSMTP_SEND_DELAY=14400/export MSMTP_SEND_DELAY=0/' ./tmp/msmtpq-ng-queueonly.rc
sed -i -e 's,^export MSMTP=.*,export MSMTP=./tests/scripts/msmtp-fail,' ./tmp/msmtpq-ng-queueonly.rc
sed -i -e 's/^export MSMTP_QUEUE_ONLY=true/export MSMTP_QUEUE_ONLY=false/' ./tmp/msmtpq-ng-queueonly.rc
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-queueonly.rc
/usr/bin/msmtpq-ng-queue -H ALL
/usr/bin/msmtpq-ng -q | grep -q 'exceeded queue lifetime; purged'
MSQRC=$?

if [ "$MSQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng -q with small max lifetime purges queue"

rm -rf ./tmp/msmtp.queue
rm -f ./tmp/msmtp.queue.log

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-fail-code-smtpd.rc

TS=PASS

echo -n "helo localhost
mail from:<root@localhost>
rcpt to:<root@localhost>
data
Subject: Testing failed sending in SMTPD

blah
.

quit
" | /usr/bin/msmtpq-ng -bs >./tmp/testbs-3.log

if grep -q "354" ./tmp/testbs-3.log && grep -q "250" ./tmp/testbs-3.log && grep -q "554" ./tmp/testbs-3.log && grep -q "221" ./tmp/testbs-3.log; then
	:
else
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtpq-ng -bs with failing send"

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi
