#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng.rc

TS=PASS

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log
echo -n "" | /usr/bin/msmtpq-ng root || TS=FAIL
grep -qi 'empty body' ./tmp/msmtp.queue.log 2>/dev/null || TS=FAIL
[ -n "$(ls -A ./tmp/msmtp.queue/*.mail 2>/dev/null)" ] && TS=FAIL

echo "$TS: Sending empty body emits log (if debug) but not error."

[ "$TS" = "FAIL" ] && OTS=FAIL || true

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-fail.rc
TS=PASS

echo "Subject: Test mail queueing

Test mail queueing" | /usr/bin/msmtpq-ng root || true

grep -q 'EX_UNAVAIL' ./tmp/msmtp.queue.log 2>/dev/null || TS=FAIL
grep -q 'Test mail queueing' ./tmp/msmtp.queue/*.mail 2>/dev/null || TS=FAIL

echo "$TS: Sending a body queues mail"

[ "$TS" = "FAIL" ] && OTS=FAIL || true

TS=PASS

/usr/bin/msmtpq-ng-queue |tail -n+3|head -n-1|head -n1|cut -f1 -d\*  >./tmp/qtestid
MQRC=$?

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Showing mail queue succeeds"

TS=PASS

/usr/bin/msmtpq-ng-queue -s $(cat ./tmp/qtestid)
MQRC=$?

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Showing single message from queue succeeds"

TS=PASS

/usr/bin/msmtpq-ng-queue -h $(cat ./tmp/qtestid)
MQRC=$?

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Putting a single message on hold succeeds"

TS=PASS

/usr/bin/msmtpq-ng-queue -i $(cat ./tmp/qtestid)|grep -q 'send failed'
MQRC=$?

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Flushing a single held message fails if no connectivty"

TS=PASS

/usr/bin/msmtpq-ng-queue -H $(cat ./tmp/qtestid)
MQRC=$?

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Taking a single message off hold succeeds"

TS=PASS

/usr/bin/msmtpq-ng-queue -d $(cat ./tmp/qtestid)
MQRC=$?

if [ "$MQRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Purging a single message succeeds"

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi
